@@ -2,12 +2,12 @@ use std::collections::HashMap;
 
 use serde_json::Value;
 
-use crate::model::interactions::ApplicationCommandPermissionType;
+use crate::model::interactions::application_command::ApplicationCommandPermissionType;
 use crate::utils;
 
 /// A builder for creating several [`ApplicationCommandPermission`].
 ///
-/// [`ApplicationCommandPermission`]: crate::model::interactions::ApplicationCommandPermission
+/// [`ApplicationCommandPermission`]: crate::model::interactions::application_command::ApplicationCommandPermission
 /// [`kind`]: Self::kind
 #[derive(Clone, Debug, Default)]
 pub struct CreateApplicationCommandsPermissions(pub Vec<Value>);
@@ -28,7 +28,7 @@ impl CreateApplicationCommandsPermissions {
         self
     }
 
-    /// Adds a new interaction.
+    /// Adds a new application command.
     pub fn add_application_command(
         &mut self,
         application_command: CreateApplicationCommandPermissions,
@@ -40,7 +40,7 @@ impl CreateApplicationCommandsPermissions {
         self
     }
 
-    /// Sets all the interactions.
+    /// Sets all the application commands.
     pub fn set_application_commands(
         &mut self,
         application_commands: Vec<CreateApplicationCommandPermissions>,
@@ -59,7 +59,7 @@ impl CreateApplicationCommandsPermissions {
 }
 /// A builder for creating an [`ApplicationCommandPermission`].
 ///
-/// [`ApplicationCommandPermission`]: crate::model::interactions::ApplicationCommandPermission
+/// [`ApplicationCommandPermission`]: crate::model::interactions::application_command::ApplicationCommandPermission
 /// [`kind`]: Self::kind
 #[derive(Clone, Debug, Default)]
 pub struct CreateApplicationCommandPermissions(pub HashMap<&'static str, Value>);
@@ -73,8 +73,8 @@ impl CreateApplicationCommandPermissions {
         self
     }
 
-    /// Creates a new permission for the interaction.
-    pub fn create_permission<F>(&mut self, f: F) -> &mut Self
+    /// Creates permissions for the application command.
+    pub fn create_permissions<F>(&mut self, f: F) -> &mut Self
     where
         F: FnOnce(
             &mut CreateApplicationCommandPermissionData,
@@ -83,13 +83,13 @@ impl CreateApplicationCommandPermissions {
         let mut data = CreateApplicationCommandPermissionData::default();
         f(&mut data);
 
-        self.add_permission(data);
+        self.add_permissions(data);
 
         self
     }
 
-    /// Adds a permission for the interaction.
-    pub fn add_permission(
+    /// Adds permission for the application command.
+    pub fn add_permissions(
         &mut self,
         permission: CreateApplicationCommandPermissionData,
     ) -> &mut Self {
@@ -103,7 +103,7 @@ impl CreateApplicationCommandPermissions {
         self
     }
 
-    /// Sets all the permissions for the interaction.
+    /// Sets permissions for the application command.
     pub fn set_permissions(
         &mut self,
         permissions: Vec<CreateApplicationCommandPermissionData>,
@@ -121,13 +121,13 @@ impl CreateApplicationCommandPermissions {
 
 /// A builder for creating several [`ApplicationCommandPermissionData`].
 ///
-/// [`ApplicationCommandPermissionData`]: crate::model::interactions::ApplicationCommandPermissionData
+/// [`ApplicationCommandPermissionData`]: crate::model::interactions::application_command::ApplicationCommandPermissionData
 /// [`kind`]: Self::kind
 #[derive(Clone, Debug, Default)]
 pub struct CreateApplicationCommandPermissionsData(pub HashMap<&'static str, Value>);
 
 impl CreateApplicationCommandPermissionsData {
-    /// Creates a permission for the interaction.
+    /// Creates a permission for the application command.
     pub fn create_permission<F>(&mut self, f: F) -> &mut Self
     where
         F: FnOnce(
@@ -142,7 +142,7 @@ impl CreateApplicationCommandPermissionsData {
         self
     }
 
-    /// Adds a permission.
+    /// Adds a permission for the application command.
     pub fn add_permission(
         &mut self,
         permission: CreateApplicationCommandPermissionData,
@@ -157,7 +157,7 @@ impl CreateApplicationCommandPermissionsData {
         self
     }
 
-    /// Sets all the permissions for the interaction.
+    /// Sets permissions for the application command.
     pub fn set_permissions(
         &mut self,
         permissions: Vec<CreateApplicationCommandPermissionData>,
@@ -199,7 +199,12 @@ impl CreateApplicationCommandPermissionData {
         self
     }
 
-    /// Sets the permission.
+    /// Sets the permission for the [`ApplicationCommandPermissionData`].
+    ///
+    /// **Note**: Setting it to `false` will only grey the application command in the
+    /// list, it will not fully hide it to the user.
+    ///
+    /// [`ApplicationCommandPermissionData`]: crate::model::interaction::ApplicationCommandPermissionData
     pub fn permission(&mut self, permission: bool) -> &mut Self {
         self.0.insert("permission", Value::Bool(permission));
         self
