@@ -15,6 +15,7 @@ mod create_application_command;
 #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
 mod create_application_command_permission;
 
+mod bot_auth_parameters;
 mod create_allowed_mentions;
 #[cfg(feature = "unstable_discord_api")]
 #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
@@ -27,6 +28,8 @@ mod create_interaction_response;
 mod create_interaction_response_followup;
 mod create_invite;
 mod create_message;
+mod create_stage_instance;
+mod create_thread;
 mod edit_channel;
 mod edit_guild;
 mod edit_guild_welcome_screen;
@@ -38,18 +41,22 @@ mod edit_member;
 mod edit_message;
 mod edit_profile;
 mod edit_role;
+mod edit_stage_instance;
 mod edit_voice_state;
 mod edit_webhook_message;
 mod execute_webhook;
 mod get_messages;
 
 pub use self::{
+    bot_auth_parameters::CreateBotAuthParameters,
     create_allowed_mentions::CreateAllowedMentions,
     create_allowed_mentions::ParseValue,
     create_channel::CreateChannel,
     create_embed::{CreateEmbed, CreateEmbedAuthor, CreateEmbedFooter, Timestamp},
     create_invite::CreateInvite,
     create_message::CreateMessage,
+    create_stage_instance::CreateStageInstance,
+    create_thread::CreateThread,
     edit_channel::EditChannel,
     edit_guild::EditGuild,
     edit_guild_welcome_screen::EditGuildWelcomeScreen,
@@ -58,6 +65,7 @@ pub use self::{
     edit_message::EditMessage,
     edit_profile::EditProfile,
     edit_role::EditRole,
+    edit_stage_instance::EditStageInstance,
     edit_voice_state::EditVoiceState,
     edit_webhook_message::EditWebhookMessage,
     execute_webhook::ExecuteWebhook,
@@ -76,7 +84,14 @@ pub use self::{
         CreateApplicationCommandPermissionsData,
         CreateApplicationCommandsPermissions,
     },
-    create_components::{CreateActionRow, CreateButton, CreateComponents},
+    create_components::{
+        CreateActionRow,
+        CreateButton,
+        CreateComponents,
+        CreateSelectMenu,
+        CreateSelectMenuOption,
+        CreateSelectMenuOptions,
+    },
     create_interaction_response::{CreateInteractionResponse, CreateInteractionResponseData},
     create_interaction_response_followup::CreateInteractionResponseFollowup,
     edit_interaction_response::EditInteractionResponse,
