@@ -86,6 +86,23 @@ impl<F: FromStr> FromStrAndCache for F {
     }
 }
 
+/// Iterator given to the selector closure in [`Cache::channel_messages_field`].
+// Wrapper around a specific iterator type to allow swapping out iterators on cache design changes
+#[derive(Clone, Debug)]
+pub struct MessageIterator<'a>(std::collections::hash_map::Values<'a, MessageId, Message>);
+
+impl<'a> Iterator for MessageIterator<'a> {
+    type Item = &'a Message;
+
+    fn next(&mut self) -> Option<&'a Message> {
+        self.0.next()
+    }
+
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        self.0.size_hint()
+    }
+}
+
 /// A cache containing data received from [`Shard`]s.
 ///
 /// Using the cache allows to avoid REST API requests via the [`http`] module
@@ -333,6 +350,28 @@ impl Cache {
         None
     }
 
+    /// This method allows to extract specific data from the cached messages of a channel by
+    /// providing a `selector` closure picking what you want to extract from the messages
+    /// iterator of a given channel.
+    ///
+    /// ```rust,no_run
+    /// # let cache: serenity::cache::Cache = todo!();
+    /// // Find all messages by user ID 8 in channel ID 7
+    /// let messages_by_user = cache.channel_messages_field(7, |msgs| {
+    ///     msgs.filter(|m| m.author.id == 8).cloned().collect::<Vec<_>>()
+    /// });
+    /// ```
+    pub async fn channel_messages_field<T>(
+        &self,
+        channel_id: impl Into<ChannelId>,
+        selector: impl FnOnce(MessageIterator<'_>) -> T,
+    ) -> Option<T> {
+        let messages = self.messages.read().await;
+        let message_iter = MessageIterator(messages.get(&channel_id.into())?.values());
+
+        Some(selector(message_iter))
+    }
+
     /// Clones an entire guild from the cache based on the given `id`.
     ///
     /// In order to clone only a field of the guild, use [`Self::guild_field`].
@@ -417,7 +456,7 @@ impl Cache {
     /// # Examples
     ///
     /// Getting a guild's channel via the Id of the message received through a
-    /// [`Client::on_message`] event dispatch:
+    /// [`EventHandler::message`] event dispatch:
     ///
     /// ```rust,no_run
     /// # use serenity::model::prelude::*;
@@ -445,14 +484,14 @@ impl Cache {
     ///
     /// # #[cfg(feature = "client")]
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    /// let mut client =Client::builder("token").event_handler(Handler).await?;
+    /// let mut client = Client::builder("token").event_handler(Handler).await?;
     ///
     /// client.start().await?;
     /// #     Ok(())
     /// # }
     /// ```
     ///
-    /// [`Client::on_message`]: ../client/struct.Client.html#method.on_message
+    /// [`EventHandler::message`]: crate::client::EventHandler::message
     #[inline]
     pub async fn guild_channel<C: Into<ChannelId>>(&self, id: C) -> Option<GuildChannel> {
         self._guild_channel(id.into()).await
@@ -513,7 +552,7 @@ impl Cache {
     /// # Examples
     ///
     /// Retrieving the member object of the user that posted a message, in a
-    /// [`Client::on_message`] context:
+    /// [`EventHandler::message`] context:
     ///
     /// ```rust,no_run
     /// # use serenity::cache::Cache;
@@ -525,7 +564,7 @@ impl Cache {
     /// # let http = Arc::new(Http::new_with_token("DISCORD_TOKEN"));
     /// # let message = ChannelId(0).message(&http, MessageId(1)).await.unwrap();
     /// # let cache = Cache::default();
-    ///
+    /// #
     /// let member = {
     ///     let channel = match cache.guild_channel(message.channel_id).await {
     ///         Some(channel) => channel,
@@ -556,7 +595,7 @@ impl Cache {
     /// # }
     /// ```
     ///
-    /// [`Client::on_message`]: ../client/struct.Client.html#method.on_message
+    /// [`EventHandler::message`]: crate::client::EventHandler::message
     /// [`members`]: crate::model::guild::Guild::members
     #[inline]
     pub async fn member<G, U>(&self, guild_id: G, user_id: U) -> Option<Member>
@@ -682,7 +721,7 @@ impl Cache {
     /// #
     /// match cache.message(message.channel_id, message.id).await {
     ///     Some(m) => assert_eq!(message.content, m.content),
-    ///     None =>println!("No message found in cache."),
+    ///     None => println!("No message found in cache."),
     /// };
     /// #     Ok(())
     /// # }
@@ -1074,6 +1113,11 @@ mod test {
             slow_mode_rate: Some(0),
             rtc_region: None,
             video_quality_mode: None,
+            message_count: None,
+            member_count: None,
+            thread_metadata: None,
+            member: None,
+            default_auto_archive_duration: None,
         };
 
         // Add a channel delete event to the cache, the cached messages for that
@@ -1131,11 +1175,14 @@ mod test {
                     approximate_member_count: None,
                     approximate_presence_count: None,
                     nsfw: false,
+                    nsfw_level: NsfwLevel::Default,
                     max_video_channel_users: None,
                     max_presences: None,
                     max_members: None,
                     widget_enabled: Some(false),
                     widget_channel_id: None,
+                    stage_instances: vec![],
+                    threads: vec![],
                 },
             }
         };
