@@ -21,7 +21,7 @@ use crate::client::{EventHandler, RawEventHandler};
 #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
 use crate::collector::ComponentInteractionFilter;
 #[cfg(feature = "collector")]
-use crate::collector::{MessageFilter, ReactionAction, ReactionFilter};
+use crate::collector::{EventFilter, LazyArc, LazyReactionAction, MessageFilter, ReactionFilter};
 #[cfg(feature = "framework")]
 use crate::framework::Framework;
 use crate::gateway::{GatewayError, InterMessage, ReconnectType, Shard, ShardAction};
@@ -29,7 +29,7 @@ use crate::internal::prelude::*;
 use crate::internal::ws_impl::{ReceiverExt, SenderExt};
 use crate::model::event::{Event, GatewayEvent};
 #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
-use crate::model::prelude::InteractionType;
+use crate::model::interactions::{Interaction, InteractionType};
 use crate::CacheAndHttp;
 
 /// A runner for managing a [`Shard`] and its respective WebSocket client.
@@ -49,6 +49,8 @@ pub struct ShardRunner {
     voice_manager: Option<Arc<dyn VoiceGatewayManager + Send + Sync + 'static>>,
     cache_and_http: Arc<CacheAndHttp>,
     #[cfg(feature = "collector")]
+    event_filters: Vec<EventFilter>,
+    #[cfg(feature = "collector")]
     message_filters: Vec<MessageFilter>,
     #[cfg(feature = "collector")]
     reaction_filters: Vec<ReactionFilter>,
@@ -75,6 +77,8 @@ impl ShardRunner {
             voice_manager: opt.voice_manager,
             cache_and_http: opt.cache_and_http,
             #[cfg(feature = "collector")]
+            event_filters: Vec::new(),
+            #[cfg(feature = "collector")]
             message_filters: Vec::new(),
             #[cfg(feature = "collector")]
             reaction_filters: Vec::new(),
@@ -214,48 +218,37 @@ impl ShardRunner {
             }
         }
 
-        // Avoid the clone if there is no message filter.
-        if !self.message_filters.is_empty() {
-            if let Event::MessageCreate(ref msg_event) = &event {
-                let msg = Arc::new(msg_event.message.clone());
-
-                retain(&mut self.message_filters, |f| f.send_message(&msg));
-            }
-        }
-
-        // Avoid the clone if there is no reaction filter.
-        if !self.reaction_filters.is_empty() {
-            match &event {
-                Event::ReactionAdd(ref reaction_event) => {
-                    let reaction =
-                        Arc::new(ReactionAction::Added(Arc::new(reaction_event.reaction.clone())));
-
-                    retain(&mut self.reaction_filters, |f| f.send_reaction(&reaction));
-                },
-                Event::ReactionRemove(ref reaction_event) => {
-                    let reaction = Arc::new(ReactionAction::Removed(Arc::new(
-                        reaction_event.reaction.clone(),
-                    )));
-
-                    retain(&mut self.reaction_filters, |f| f.send_reaction(&reaction));
-                },
-                _ => {},
-            }
-        }
-
-        // Avoid the clone if there is no interaction filter.
-        #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
-        if !self.component_interaction_filters.is_empty() {
-            if let Event::InteractionCreate(ref interaction_event) = &event {
-                if interaction_event.interaction.kind == InteractionType::MessageComponent {
-                    let interaction = Arc::new(interaction_event.interaction.clone());
-
-                    retain(&mut self.component_interaction_filters, |f| {
-                        f.send_interaction(&interaction)
-                    });
+        match &event {
+            Event::MessageCreate(ref msg_event) => {
+                let mut msg = LazyArc::new(&msg_event.message);
+                retain(&mut self.message_filters, |f| f.send_message(&mut msg));
+            },
+            Event::ReactionAdd(ref reaction_event) => {
+                let mut reaction = LazyReactionAction::new(&reaction_event.reaction, true);
+                retain(&mut self.reaction_filters, |f| f.send_reaction(&mut reaction));
+            },
+            Event::ReactionRemove(ref reaction_event) => {
+                let mut reaction = LazyReactionAction::new(&reaction_event.reaction, false);
+                retain(&mut self.reaction_filters, |f| f.send_reaction(&mut reaction));
+            },
+            #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
+            Event::InteractionCreate(ref interaction_event) => {
+                if interaction_event.interaction.kind() == InteractionType::MessageComponent {
+                    if let Interaction::MessageComponent(ref interaction) =
+                        interaction_event.interaction
+                    {
+                        let mut interaction = LazyArc::new(interaction);
+                        retain(&mut self.component_interaction_filters, |f| {
+                            f.send_interaction(&mut interaction)
+                        });
+                    }
                 }
-            }
+            },
+            _ => {},
         }
+
+        let mut event = LazyArc::new(event);
+        retain(&mut self.event_filters, |f| f.send_event(&mut event));
     }
 
     /// Clones the internal copy of the Sender to the shard runner.
@@ -450,6 +443,12 @@ impl ShardRunner {
                     self.shard.update_presence().await.is_ok()
                 },
                 #[cfg(feature = "collector")]
+                ShardClientMessage::Runner(ShardRunnerMessage::SetEventFilter(collector)) => {
+                    self.event_filters.push(collector);
+
+                    true
+                },
+                #[cfg(feature = "collector")]
                 ShardClientMessage::Runner(ShardRunnerMessage::SetMessageFilter(collector)) => {
                     self.message_filters.push(collector);
 
