@@ -177,7 +177,7 @@ pub(crate) fn dispatch<'rec>(
                             &cache_and_http.cache,
                         );
 
-                        let framework = Arc::clone(&framework);
+                        let framework = Arc::clone(framework);
 
                         tokio::spawn(async move {
                             framework.dispatch(context, event.message).await;
@@ -210,7 +210,7 @@ pub(crate) fn dispatch<'rec>(
                     {
                         dispatch_message(context.clone(), event.message.clone(), h).await;
 
-                        let framework = Arc::clone(&framework);
+                        let framework = Arc::clone(framework);
 
                         tokio::spawn(async move {
                             framework.dispatch(context, event.message).await;
@@ -251,7 +251,7 @@ pub(crate) fn dispatch<'rec>(
                             let message = msg_event.message.clone();
                             event_handler.raw_event(context.clone(), event).await;
 
-                            let framework = Arc::clone(&framework);
+                            let framework = Arc::clone(framework);
 
                             tokio::spawn(async move {
                                 framework.dispatch(context, message).await;
@@ -288,7 +288,7 @@ pub(crate) fn dispatch<'rec>(
                         {
                             dispatch_message(context.clone(), event.message.clone(), handler).await;
 
-                            let framework = Arc::clone(&framework);
+                            let framework = Arc::clone(framework);
                             let message = event.message;
                             tokio::spawn(async move {
                                 framework.dispatch(context, message).await;
@@ -687,14 +687,14 @@ async fn handle_event(
         },
         DispatchEvent::Model(Event::Ready(mut event)) => {
             update(&cache_and_http, &mut event).await;
-            let event_handler = Arc::clone(&event_handler);
+            let event_handler = Arc::clone(event_handler);
 
             tokio::spawn(async move {
                 event_handler.ready(context, event.ready).await;
             });
         },
         DispatchEvent::Model(Event::Resumed(event)) => {
-            let event_handler = Arc::clone(&event_handler);
+            let event_handler = Arc::clone(event_handler);
 
             tokio::spawn(async move {
                 event_handler.resume(context, event).await;
@@ -810,5 +810,68 @@ async fn handle_event(
                 event_handler.application_command_delete(context, event.application_command).await;
             });
         },
+        DispatchEvent::Model(Event::StageInstanceCreate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.stage_instance_create(context, event.stage_instance).await;
+            });
+        },
+        DispatchEvent::Model(Event::StageInstanceUpdate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.stage_instance_update(context, event.stage_instance).await;
+            });
+        },
+        DispatchEvent::Model(Event::StageInstanceDelete(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.stage_instance_delete(context, event.stage_instance).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadCreate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_create(context, event.thread).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadUpdate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_update(context, event.thread).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadDelete(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_delete(context, event.thread).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadListSync(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_list_sync(context, event).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadMemberUpdate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_member_update(context, event.member).await;
+            });
+        },
+        DispatchEvent::Model(Event::ThreadMembersUpdate(event)) => {
+            let event_handler = Arc::clone(event_handler);
+
+            tokio::spawn(async move {
+                event_handler.thread_members_update(context, event).await;
+            });
+        },
     }
 }
