@@ -5,6 +5,8 @@ use serde_json::Value;
 
 use super::context::Context;
 use crate::client::bridge::gateway::event::*;
+#[cfg(feature = "unstable_discord_api")]
+use crate::model::interactions::{application_command::ApplicationCommand, Interaction};
 use crate::model::prelude::*;
 
 /// The core trait for handling events by serenity.
@@ -422,7 +424,7 @@ pub trait EventHandler: Send + Sync {
     ) {
     }
 
-    /// Dispatched when a user used a slash command.
+    /// Dispatched when an interaction is created (e.g a slash command was used or a button was clicked).
     ///
     /// Provides the created interaction.
     #[cfg(feature = "unstable_discord_api")]
@@ -492,6 +494,62 @@ pub trait EventHandler: Send + Sync {
         _application_command: ApplicationCommand,
     ) {
     }
+
+    /// Dispatched when a stage instance is created.
+    ///
+    /// Provides the created stage instance.
+    async fn stage_instance_create(&self, _ctx: Context, _stage_instance: StageInstance) {}
+
+    /// Dispatched when a stage instance is updated.
+    ///
+    /// Provides the updated stage instance.
+    async fn stage_instance_update(&self, _ctx: Context, _stage_instance: StageInstance) {}
+
+    /// Dispatched when a stage instance is deleted.
+    ///
+    /// Provides the deleted stage instance.
+    async fn stage_instance_delete(&self, _ctx: Context, _stage_instance: StageInstance) {}
+
+    /// Dispatched when a thread is created or the current user is added
+    /// to a private thread.
+    ///
+    /// Provides the thread.
+    async fn thread_create(&self, _ctx: Context, _thread: GuildChannel) {}
+
+    /// Dispatched when a thread is updated.
+    ///
+    /// Provides the updated thread.
+    async fn thread_update(&self, _ctx: Context, _thread: GuildChannel) {}
+
+    /// Dispatched when a thread is deleted.
+    ///
+    /// Provides the partial deleted thread.
+    async fn thread_delete(&self, _ctx: Context, _thread: PartialGuildChannel) {}
+
+    /// Dispatched when the current user gains access to a channel
+    ///
+    /// Provides the threads the current user can access, the thread members,
+    /// the guild Id, and the channel Ids of the parent channels being synced.
+    async fn thread_list_sync(&self, _ctx: Context, _thread_list_sync: ThreadListSyncEvent) {}
+
+    /// Dispatched when the [`ThreadMember`] for the current user is updated.
+    ///
+    /// Provides the updated thread member.
+    async fn thread_member_update(&self, _ctx: Context, _thread_member: ThreadMember) {}
+
+    /// Dispatched when anyone is added to or removed from a thread. If the current user does not have the [`GatewayIntents::GUILDS`],
+    /// then this event will only be sent if the current user was added to or removed from the thread.
+    ///
+    /// Provides the added/removed members, the approximate member count of members in the thread,
+    /// the thread Id and its guild Id.
+    ///
+    /// [`GatewayIntents::GUILDS`]: crate::client::bridge::gateway::GatewayIntents::GUILDS
+    async fn thread_members_update(
+        &self,
+        _ctx: Context,
+        _thread_members_update: ThreadMembersUpdateEvent,
+    ) {
+    }
 }
 
 /// This core trait for handling raw events
