@@ -62,6 +62,8 @@ pub use self::{
 use super::gateway::GatewayError;
 #[cfg(feature = "cache")]
 pub use crate::cache::Cache;
+#[cfg(feature = "cache")]
+use crate::cache::Settings as CacheSettings;
 #[cfg(feature = "framework")]
 use crate::framework::Framework;
 use crate::http::Http;
@@ -86,6 +88,8 @@ pub struct ClientBuilder<'a> {
     application_id: Option<ApplicationId>,
     #[cfg(feature = "cache")]
     timeout: Option<Duration>,
+    #[cfg(feature = "cache")]
+    cache_settings: Option<CacheSettings>,
     #[cfg(feature = "framework")]
     framework: Option<Arc<Box<dyn Framework + Send + Sync + 'static>>>,
     #[cfg(feature = "voice")]
@@ -107,6 +111,8 @@ impl<'a> ClientBuilder<'a> {
             application_id: None,
             #[cfg(feature = "cache")]
             timeout: None,
+            #[cfg(feature = "cache")]
+            cache_settings: Some(CacheSettings::new()),
             #[cfg(feature = "framework")]
             framework: None,
             #[cfg(feature = "voice")]
@@ -208,6 +214,22 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Sets the settings of the cache.
+    /// Refer to [`Settings`] for more information.
+    ///
+    /// [`Settings`]: self::CacheSettings
+    #[cfg(feature = "cache")]
+    pub fn cache_settings<F>(mut self, f: F) -> Self
+    where
+        F: FnOnce(&mut CacheSettings) -> &mut CacheSettings,
+    {
+        if let Some(ref mut settings) = self.cache_settings {
+            f(settings);
+        }
+
+        self
+    }
+
     /// Sets the command framework to be used. It will receive messages sent
     /// over the gateway and then consider - based on its settings - whether to
     /// dispatch a command.
@@ -347,7 +369,7 @@ impl<'a> Future for ClientBuilder<'a> {
 
             let cache_and_http = Arc::new(CacheAndHttp {
                 #[cfg(feature = "cache")]
-                cache: Arc::new(Cache::default()),
+                cache: Arc::new(Cache::new_with_settings(self.cache_settings.take().unwrap())),
                 #[cfg(feature = "cache")]
                 update_cache_timeout: self.timeout.take(),
                 http: Arc::clone(&http),
@@ -1013,7 +1035,7 @@ pub fn parse_token(token: impl AsRef<str>) -> Option<TokenComponents> {
     let timestamp = chrono::NaiveDateTime::from_timestamp_opt(timestamp as i64, 0)?;
 
     // Third part is a base64-encoded HMAC that's not interesting on its own
-    let _ = base64::decode(parts.get(2)?).ok()?;
+    let _ = base64::decode_config(parts.get(2)?, base64_config).ok()?;
 
     Some(TokenComponents {
         bot_user_id: user_id,
