@@ -260,8 +260,10 @@ impl StandardFramework {
                     return Some(DispatchError::BlockedGuild);
                 }
 
-                if let Some(guild) = guild_id.to_guild_cached(&ctx.cache).await {
-                    if self.config.blocked_users.contains(&guild.owner_id) {
+                let owner_id_option = ctx.cache.guild_field(guild_id, |guild| guild.owner_id).await;
+
+                if let Some(owner_id) = owner_id_option {
+                    if self.config.blocked_users.contains(&owner_id) {
                         return Some(DispatchError::BlockedGuild);
                     }
                 }
@@ -379,8 +381,8 @@ impl StandardFramework {
     pub fn group_add(&mut self, group: &'static CommandGroup) {
         let map = if group.options.prefixes.is_empty() {
             Map::Prefixless(
-                GroupMap::new(&group.options.sub_groups, &self.config),
-                CommandMap::new(&group.options.commands, &self.config),
+                GroupMap::new(group.options.sub_groups, &self.config),
+                CommandMap::new(group.options.commands, &self.config),
             )
         } else {
             Map::WithPrefixes(GroupMap::new(&[group], &self.config))
@@ -719,7 +721,7 @@ impl Framework for StandardFramework {
                 };
 
                 if let Some(error) =
-                    self.should_fail(&ctx, &msg, &mut args, &command.options, &group.options).await
+                    self.should_fail(&ctx, &msg, &mut args, command.options, group.options).await
                 {
                     if let Some(dispatch) = &self.dispatch {
                         dispatch(&mut ctx, &msg, error).await;
@@ -773,11 +775,11 @@ impl CommonOptions for &GroupOptions {
     }
 
     fn allowed_roles(&self) -> &'static [&'static str] {
-        &self.allowed_roles
+        self.allowed_roles
     }
 
     fn checks(&self) -> &'static [&'static Check] {
-        &self.checks
+        self.checks
     }
 
     fn only_in(&self) -> OnlyIn {
@@ -803,11 +805,11 @@ impl CommonOptions for &CommandOptions {
     }
 
     fn allowed_roles(&self) -> &'static [&'static str] {
-        &self.allowed_roles
+        self.allowed_roles
     }
 
     fn checks(&self) -> &'static [&'static Check] {
-        &self.checks
+        self.checks
     }
 
     fn only_in(&self) -> OnlyIn {
@@ -835,32 +837,35 @@ pub(crate) async fn has_correct_permissions(
 ) -> bool {
     if options.required_permissions().is_empty() {
         true
-    } else if let Some(guild) = message.guild(&cache).await {
-        let channel = match guild.channels.get(&message.channel_id) {
-            Some(channel) => channel,
-            None => return false,
-        };
-        let member = match guild.members.get(&message.author.id) {
-            Some(member) => member,
-            None => return false,
-        };
-
-        let perms = match guild.user_permissions_in(channel, member) {
-            Ok(perms) => perms,
-            Err(e) => {
-                tracing::error!(
-                    "Error getting permissions for user {} in channel {}: {}",
-                    member.user.id,
-                    channel.id,
-                    e
-                );
-                return false;
-            },
-        };
-
-        perms.contains(*options.required_permissions())
     } else {
-        false
+        message
+            .guild_field(cache, |guild| {
+                let channel = match guild.channels.get(&message.channel_id) {
+                    Some(channel) => channel,
+                    None => return false,
+                };
+
+                let member = match guild.members.get(&message.author.id) {
+                    Some(member) => member,
+                    None => return false,
+                };
+
+                match guild.user_permissions_in(channel, member) {
+                    Ok(perms) => perms.contains(*options.required_permissions()),
+                    Err(e) => {
+                        tracing::error!(
+                            "Error getting permissions for user {} in channel {}: {}",
+                            member.user.id,
+                            channel.id,
+                            e
+                        );
+
+                        false
+                    },
+                }
+            })
+            .await
+            .unwrap_or(false)
     }
 }
 
