@@ -53,8 +53,7 @@ use crate::model::{
 /// leave the client to do it.
 ///
 /// This can be done by passing in the required parameters to [`Self::new`]. You can
-/// then manually handle the shard yourself and receive events via
-/// [`receive`].
+/// then manually handle the shard yourself.
 ///
 /// **Note**: You _really_ do not need to do this. Just call one of the
 /// appropriate methods on the [`Client`].
@@ -178,12 +177,6 @@ impl Shard {
     }
 
     /// Whether the shard has permanently shutdown.
-    ///
-    /// This should normally happen due to manual calling of [`shutdown`] or
-    /// [`shutdown_clean`].
-    ///
-    /// [`shutdown`]: #method.shutdown
-    /// [`shutdown_clean`]: #method.shutdown_clean
     #[inline]
     pub fn is_shutdown(&self) -> bool {
         self.shutdown
@@ -549,9 +542,7 @@ impl Shard {
                 }))
             },
             Ok(GatewayEvent::Reconnect) => Ok(Some(ShardAction::Reconnect(ReconnectType::Resume))),
-            Err(Error::Gateway(GatewayError::Closed(ref data))) => {
-                self.handle_gateway_closed(&data)
-            },
+            Err(Error::Gateway(GatewayError::Closed(ref data))) => self.handle_gateway_closed(data),
             Err(Error::Tungstenite(ref why)) => {
                 warn!("[Shard {:?}] Websocket error: {:?}", self.shard_info, why);
                 info!("[Shard {:?}] Will attempt to auto-reconnect", self.shard_info);
@@ -767,7 +758,7 @@ impl Shard {
         self.stage = ConnectionStage::Connecting;
         self.started = Instant::now();
         let url = &self.ws_url.lock().await.clone();
-        let client = connect(&url).await?;
+        let client = connect(url).await?;
         self.stage = ConnectionStage::Handshake;
 
         Ok(client)
