@@ -110,6 +110,60 @@ pub enum Route {
     ///
     /// [`ChannelId`]: crate::model::id::ChannelId
     ChannelsIdWebhooks(u64),
+    /// Route for the `/channels/:channel_id/messages/:message_id/threads` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdMessagesIdThreads(u64),
+    /// Route for the `/channels/:channel_id/threads` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdThreads(u64),
+    /// Route for the `/channels/:channel_id/thread-members/@me` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdThreadMembersMe(u64),
+    /// Route for the `/channels/:channel_id/thread-members/:user_id` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdThreadMembersUserId(u64),
+    /// Route for the `/channels/channel_id/thread-members` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdThreadMembers(u64),
+    /// Route for the `/channels/:channel_id/threads/active` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdActiveThreads(u64),
+    /// Route for the `/channels/:channel_id/threads/archived/public` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdArchivedPublicThreads(u64),
+    /// Route for the `/channels/:channel_id/threads/archived/private` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdArchivedPrivateThreads(u64),
+    /// Route for the `/channels/:channel_id/users/@me/threads/archived/private` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    ChannelsIdMeJoindedArchivedPrivateThreads(u64),
     /// Route for the `/gateway` path.
     Gateway,
     /// Route for the `/gateway/bot` path.
@@ -212,12 +266,24 @@ pub enum Route {
     ///
     /// [`GuildId`]: crate::model::id::GuildId
     GuildsIdMembersIdRolesId(u64),
+    /// Route for the `/guilds/:guild_id/members/@me` path.
+    ///
+    /// The data is the relevant [`GuildId`].
+    ///
+    /// [`GuildId`]: crate::model::id::GuildId
+    GuildsIdMembersMe(u64),
     /// Route for the `/guilds/:guild_id/members/@me/nick` path.
     ///
     /// The data is the relevant [`GuildId`].
     ///
     /// [`GuildId`]: crate::model::id::GuildId
     GuildsIdMembersMeNick(u64),
+    /// Route for the `/guilds/:guild_id/members/search` path.
+    ///
+    /// The data is the relevant [`GuildId`].
+    ///
+    /// [`GuildId`]: crate::model::id::GuildId
+    GuildsIdMembersSearch(u64),
     /// Route for the `/guilds/:guild_id/prune` path.
     ///
     /// The data is the relevant [`GuildId`].
@@ -280,6 +346,8 @@ pub enum Route {
     UsersMe,
     /// Route for the `/users/@me/channels` path.
     UsersMeChannels,
+    /// Route for the `/users/@me/connections` path.
+    UsersMeConnections,
     /// Route for the `/users/@me/guilds` path.
     UsersMeGuilds,
     /// Route for the `/users/@me/guilds/:guild_id` path.
@@ -358,6 +426,18 @@ pub enum Route {
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdGuildsIdCommandsId(u64),
+    /// Route for the `/stage-instances` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    StageInstances,
+    /// Route for the `/stage-instances/:channel_id` path.
+    ///
+    /// The data is the relevant [`ChannelId`].
+    ///
+    /// [`ChannelId`]: crate::model::id::ChannelId
+    StageInstancesChannelId(u64),
     /// Route where no ratelimit headers are in place (i.e. user account-only
     /// routes).
     ///
@@ -417,6 +497,7 @@ impl Route {
         api!("/channels/{}/messages/{}/reactions", channel_id, message_id)
     }
 
+    #[allow(clippy::let_underscore_must_use)]
     pub fn channel_message_reactions_list(
         channel_id: u64,
         message_id: u64,
@@ -430,7 +511,6 @@ impl Route {
         );
 
         if let Some(after) = after {
-            #[allow(clippy::let_underscore_must_use)]
             let _ = write!(uri, "&after={}", after);
         }
 
@@ -465,6 +545,87 @@ impl Route {
         format!(api!("/channels/{}/webhooks"), channel_id)
     }
 
+    pub fn channel_public_threads(channel_id: u64, message_id: u64) -> String {
+        format!(api!("/channels/{}/messages/{}/threads"), channel_id, message_id)
+    }
+
+    pub fn channel_private_threads(channel_id: u64) -> String {
+        format!(api!("/channels/{}/threads"), channel_id)
+    }
+
+    pub fn channel_thread_member(channel_id: u64, user_id: u64) -> String {
+        format!(api!("/channels/{}/thread-members/{}"), channel_id, user_id)
+    }
+
+    pub fn channel_thread_member_me(channel_id: u64) -> String {
+        format!(api!("/channels/{}/thread-members/@me"), channel_id)
+    }
+
+    pub fn channel_thread_members(channel_id: u64) -> String {
+        format!(api!("/channels/{}/thread-members"), channel_id)
+    }
+
+    pub fn channel_active_threads(channel_id: u64) -> String {
+        format!(api!("/channels/{}/threads/active"), channel_id)
+    }
+
+    #[allow(clippy::let_underscore_must_use)]
+    pub fn channel_archived_public_threads(
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> String {
+        let mut s = format!(api!("/channels/{}/threads/archived/public"), channel_id);
+
+        if let Some(id) = before {
+            let _ = write!(s, "&before={}", id);
+        }
+
+        if let Some(limit) = limit {
+            let _ = write!(s, "&limit={}", limit);
+        }
+
+        s
+    }
+
+    #[allow(clippy::let_underscore_must_use)]
+    pub fn channel_archived_private_threads(
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> String {
+        let mut s = format!(api!("/channels/{}/threads/archived/private"), channel_id);
+
+        if let Some(id) = before {
+            let _ = write!(s, "&before={}", id);
+        }
+
+        if let Some(limit) = limit {
+            let _ = write!(s, "&limit={}", limit);
+        }
+
+        s
+    }
+
+    #[allow(clippy::let_underscore_must_use)]
+    pub fn channel_joined_private_threads(
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> String {
+        let mut s = format!(api!("/channels/{}/users/@me/threads/archived/private"), channel_id);
+
+        if let Some(id) = before {
+            let _ = write!(s, "&before={}", id);
+        }
+
+        if let Some(limit) = limit {
+            let _ = write!(s, "&limit={}", limit);
+        }
+
+        s
+    }
+
     pub fn gateway() -> &'static str {
         api!("/gateway")
     }
@@ -582,22 +743,36 @@ impl Route {
         format!(api!("/guilds/{}/members"), guild_id)
     }
 
+    #[allow(clippy::let_underscore_must_use)]
+    pub fn guild_members_search(guild_id: u64, query: &str, limit: Option<u64>) -> String {
+        let mut s = format!(api!("/guilds/{}/members/search?"), guild_id);
+
+        let _ = write!(s, "&query={}", query);
+
+        let _ = write!(s, "&limit={}", limit.unwrap_or(constants::MEMBER_FETCH_LIMIT));
+
+        s
+    }
+
+    #[allow(clippy::let_underscore_must_use)]
     pub fn guild_members_optioned(guild_id: u64, after: Option<u64>, limit: Option<u64>) -> String {
         let mut s = format!(api!("/guilds/{}/members?"), guild_id);
 
         if let Some(after) = after {
-            #[allow(clippy::let_underscore_must_use)]
             let _ = write!(s, "&after={}", after);
             // should not error, ignoring
         }
 
-        #[allow(clippy::let_underscore_must_use)]
         let _ = write!(s, "&limit={}", limit.unwrap_or(constants::MEMBER_FETCH_LIMIT));
         // should not error, ignoring
 
         s
     }
 
+    pub fn guild_member_me(guild_id: u64) -> String {
+        format!(api!("/guilds/{}/members/@me"), guild_id)
+    }
+
     pub fn guild_nickname(guild_id: u64) -> String {
         format!(api!("/guilds/{}/members/@me/nick"), guild_id)
     }
@@ -674,6 +849,10 @@ impl Route {
         format!(api!("/users/{}"), target)
     }
 
+    pub fn user_me_connections() -> &'static str {
+        api!("/users/@me/connections")
+    }
+
     pub fn user_dm_channels<D: Display>(target: D) -> String {
         format!(api!("/users/{}/channels"), target)
     }
@@ -686,6 +865,7 @@ impl Route {
         format!(api!("/users/{}/guilds"), target)
     }
 
+    #[allow(clippy::let_underscore_must_use)]
     pub fn user_guilds_optioned<D: Display>(
         target: D,
         after: Option<u64>,
@@ -695,13 +875,11 @@ impl Route {
         let mut s = format!(api!("/users/{}/guilds?limit={}&"), target, limit);
 
         if let Some(after) = after {
-            #[allow(clippy::let_underscore_must_use)]
             let _ = write!(s, "&after={}", after);
             // should not error, ignoring
         }
 
         if let Some(before) = before {
-            #[allow(clippy::let_underscore_must_use)]
             let _ = write!(s, "&before={}", before);
             // should not error, ignoring
         }
@@ -818,6 +996,14 @@ impl Route {
     pub fn application_guild_commands_permissions(application_id: u64, guild_id: u64) -> String {
         format!(api!("/applications/{}/guilds/{}/commands/permissions"), application_id, guild_id)
     }
+
+    pub fn stage_instances() -> String {
+        api!("/stage-instances").to_string()
+    }
+
+    pub fn stage_instance(channel_id: u64) -> String {
+        format!(api!("/stage-instances/{}"), channel_id)
+    }
 }
 
 #[derive(Clone, Debug)]
@@ -840,6 +1026,14 @@ pub enum RouteInfo<'a> {
     CreateChannel {
         guild_id: u64,
     },
+    CreateStageInstance,
+    CreatePublicThread {
+        channel_id: u64,
+        message_id: u64,
+    },
+    CreatePrivateThread {
+        channel_id: u64,
+    },
     CreateEmoji {
         guild_id: u64,
     },
@@ -907,6 +1101,9 @@ pub enum RouteInfo<'a> {
     DeleteChannel {
         channel_id: u64,
     },
+    DeleteStageInstance {
+        channel_id: u64,
+    },
     DeleteEmoji {
         guild_id: u64,
         emoji_id: u64,
@@ -992,6 +1189,9 @@ pub enum RouteInfo<'a> {
     EditChannel {
         channel_id: u64,
     },
+    EditStageInstance {
+        channel_id: u64,
+    },
     EditEmoji {
         guild_id: u64,
         emoji_id: u64,
@@ -1053,6 +1253,9 @@ pub enum RouteInfo<'a> {
         channel_id: u64,
         message_id: u64,
     },
+    EditMemberMe {
+        guild_id: u64,
+    },
     EditNickname {
         guild_id: u64,
     },
@@ -1100,6 +1303,20 @@ pub enum RouteInfo<'a> {
         wait: bool,
         webhook_id: u64,
     },
+    JoinThread {
+        channel_id: u64,
+    },
+    LeaveThread {
+        channel_id: u64,
+    },
+    AddThreadMember {
+        channel_id: u64,
+        user_id: u64,
+    },
+    RemoveThreadMember {
+        channel_id: u64,
+        user_id: u64,
+    },
     GetActiveMaintenance,
     GetAuditLogs {
         action_type: Option<u8>,
@@ -1124,6 +1341,30 @@ pub enum RouteInfo<'a> {
     GetChannels {
         guild_id: u64,
     },
+    GetStageInstance {
+        channel_id: u64,
+    },
+    GetChannelThreadMembers {
+        channel_id: u64,
+    },
+    GetChannelActiveThreads {
+        channel_id: u64,
+    },
+    GetChannelArchivedPublicThreads {
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    },
+    GetChannelArchivedPrivateThreads {
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    },
+    GetChannelJoinedPrivateArchivedThreads {
+        channel_id: u64,
+        before: Option<u64>,
+        limit: Option<u64>,
+    },
     GetCurrentApplicationInfo,
     GetCurrentUser,
     GetEmojis {
@@ -1249,6 +1490,7 @@ pub enum RouteInfo<'a> {
     GetUser {
         user_id: u64,
     },
+    GetUserConnections,
     GetUserDmChannels,
     GetVoiceRegions,
     GetWebhook {
@@ -1282,6 +1524,11 @@ pub enum RouteInfo<'a> {
         role_id: u64,
         user_id: u64,
     },
+    SearchGuildMembers {
+        guild_id: u64,
+        query: &'a str,
+        limit: Option<u64>,
+    },
     StartGuildPrune {
         days: u64,
         guild_id: u64,
@@ -1341,6 +1588,24 @@ impl<'a> RouteInfo<'a> {
                 Route::GuildsIdChannels(guild_id),
                 Cow::from(Route::guild_channels(guild_id)),
             ),
+            RouteInfo::CreateStageInstance => {
+                (LightMethod::Post, Route::StageInstances, Cow::from(Route::stage_instances()))
+            },
+            RouteInfo::CreatePublicThread {
+                channel_id,
+                message_id,
+            } => (
+                LightMethod::Post,
+                Route::ChannelsIdMessagesIdThreads(channel_id),
+                Cow::from(Route::channel_public_threads(channel_id, message_id)),
+            ),
+            RouteInfo::CreatePrivateThread {
+                channel_id,
+            } => (
+                LightMethod::Post,
+                Route::ChannelsIdThreads(channel_id),
+                Cow::from(Route::channel_private_threads(channel_id)),
+            ),
             RouteInfo::CreateEmoji {
                 guild_id,
             } => (
@@ -1476,6 +1741,13 @@ impl<'a> RouteInfo<'a> {
                 Route::ChannelsId(channel_id),
                 Cow::from(Route::channel(channel_id)),
             ),
+            RouteInfo::DeleteStageInstance {
+                channel_id,
+            } => (
+                LightMethod::Delete,
+                Route::StageInstancesChannelId(channel_id),
+                Cow::from(Route::stage_instance(channel_id)),
+            ),
             RouteInfo::DeleteEmoji {
                 emoji_id,
                 guild_id,
@@ -1634,6 +1906,13 @@ impl<'a> RouteInfo<'a> {
                 Route::ChannelsId(channel_id),
                 Cow::from(Route::channel(channel_id)),
             ),
+            RouteInfo::EditStageInstance {
+                channel_id,
+            } => (
+                LightMethod::Patch,
+                Route::StageInstancesChannelId(channel_id),
+                Cow::from(Route::stage_instance(channel_id)),
+            ),
             RouteInfo::EditEmoji {
                 emoji_id,
                 guild_id,
@@ -1738,6 +2017,13 @@ impl<'a> RouteInfo<'a> {
                 Route::ChannelsIdMessagesId(LightMethod::Patch, channel_id),
                 Cow::from(Route::channel_message(channel_id, message_id)),
             ),
+            RouteInfo::EditMemberMe {
+                guild_id,
+            } => (
+                LightMethod::Patch,
+                Route::GuildsIdMembersMe(guild_id),
+                Cow::from(Route::guild_member_me(guild_id)),
+            ),
             RouteInfo::EditNickname {
                 guild_id,
             } => (
@@ -1866,6 +2152,13 @@ impl<'a> RouteInfo<'a> {
                 Route::ChannelsId(channel_id),
                 Cow::from(Route::channel(channel_id)),
             ),
+            RouteInfo::GetStageInstance {
+                channel_id,
+            } => (
+                LightMethod::Get,
+                Route::StageInstancesChannelId(channel_id),
+                Cow::from(Route::stage_instance(channel_id)),
+            ),
             RouteInfo::GetChannelInvites {
                 channel_id,
             } => (
@@ -1887,6 +2180,77 @@ impl<'a> RouteInfo<'a> {
                 Route::GuildsIdChannels(guild_id),
                 Cow::from(Route::guild_channels(guild_id)),
             ),
+            RouteInfo::GetChannelThreadMembers {
+                channel_id,
+            } => (
+                LightMethod::Get,
+                Route::ChannelsIdThreadMembers(channel_id),
+                Cow::from(Route::channel_thread_members(channel_id)),
+            ),
+            RouteInfo::GetChannelActiveThreads {
+                channel_id,
+            } => (
+                LightMethod::Get,
+                Route::ChannelsIdActiveThreads(channel_id),
+                Cow::from(Route::channel_active_threads(channel_id)),
+            ),
+            RouteInfo::GetChannelArchivedPublicThreads {
+                channel_id,
+                before,
+                limit,
+            } => (
+                LightMethod::Get,
+                Route::ChannelsIdArchivedPublicThreads(channel_id),
+                Cow::from(Route::channel_archived_public_threads(channel_id, before, limit)),
+            ),
+            RouteInfo::GetChannelArchivedPrivateThreads {
+                channel_id,
+                before,
+                limit,
+            } => (
+                LightMethod::Get,
+                Route::ChannelsIdArchivedPrivateThreads(channel_id),
+                Cow::from(Route::channel_archived_private_threads(channel_id, before, limit)),
+            ),
+            RouteInfo::GetChannelJoinedPrivateArchivedThreads {
+                channel_id,
+                before,
+                limit,
+            } => (
+                LightMethod::Get,
+                Route::ChannelsIdMeJoindedArchivedPrivateThreads(channel_id),
+                Cow::from(Route::channel_joined_private_threads(channel_id, before, limit)),
+            ),
+            RouteInfo::JoinThread {
+                channel_id,
+            } => (
+                LightMethod::Put,
+                Route::ChannelsIdThreadMembersMe(channel_id),
+                Cow::from(Route::channel_thread_member_me(channel_id)),
+            ),
+            RouteInfo::LeaveThread {
+                channel_id,
+            } => (
+                LightMethod::Delete,
+                Route::ChannelsIdThreadMembersMe(channel_id),
+                Cow::from(Route::channel_thread_member_me(channel_id)),
+            ),
+            RouteInfo::AddThreadMember {
+                channel_id,
+                user_id,
+            } => (
+                LightMethod::Put,
+                Route::ChannelsIdThreadMembersUserId(channel_id),
+                Cow::from(Route::channel_thread_member(channel_id, user_id)),
+            ),
+            RouteInfo::RemoveThreadMember {
+                channel_id,
+                user_id,
+            } => (
+                LightMethod::Delete,
+                Route::ChannelsIdThreadMembersUserId(channel_id),
+                Cow::from(Route::channel_thread_member(channel_id, user_id)),
+            ),
             RouteInfo::GetCurrentApplicationInfo => {
                 (LightMethod::Get, Route::None, Cow::from(Route::oauth2_application_current()))
             },
@@ -2130,6 +2494,11 @@ impl<'a> RouteInfo<'a> {
             RouteInfo::GetUser {
                 user_id,
             } => (LightMethod::Get, Route::UsersId, Cow::from(Route::user(user_id))),
+            RouteInfo::GetUserConnections => (
+                LightMethod::Get,
+                Route::UsersMeConnections,
+                Cow::from(Route::user_me_connections()),
+            ),
             RouteInfo::GetUserDmChannels => (
                 LightMethod::Get,
                 Route::UsersMeChannels,
@@ -2201,6 +2570,15 @@ impl<'a> RouteInfo<'a> {
                 Route::GuildsIdMembersIdRolesId(guild_id),
                 Cow::from(Route::guild_member_role(guild_id, user_id, role_id)),
             ),
+            RouteInfo::SearchGuildMembers {
+                guild_id,
+                query,
+                limit,
+            } => (
+                LightMethod::Get,
+                Route::GuildsIdMembersSearch(guild_id),
+                Cow::from(Route::guild_members_search(guild_id, query, limit)),
+            ),
             RouteInfo::StartGuildPrune {
                 days,
                 guild_id,
