@@ -14,7 +14,15 @@ use serde_json::json;
 use tokio::{fs::File, io::AsyncReadExt};
 
 #[cfg(feature = "model")]
-use crate::builder::{CreateInvite, CreateMessage, EditChannel, EditMessage, GetMessages};
+use crate::builder::{
+    CreateInvite,
+    CreateMessage,
+    CreateThread,
+    EditChannel,
+    EditMessage,
+    GetMessages,
+};
+use crate::builder::{CreateStageInstance, EditStageInstance};
 #[cfg(all(feature = "cache", feature = "model"))]
 use crate::cache::Cache;
 #[cfg(feature = "collector")]
@@ -557,8 +565,9 @@ impl ChannelId {
     /// **Note**: Only available on announcements channels.
     ///
     /// # Errors
-    // Returns [`Error::Http`] if the current user lacks permission,
-    // and if the user is not the author of the message.
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission,
+    /// and if the user is not the author of the message.
     /// [Manage Messages]: Permissions::MANAGE_MESSAGES
     pub async fn crosspost(
         &self,
@@ -970,6 +979,218 @@ impl ChannelId {
     ) -> ReactionCollectorBuilder<'a> {
         ReactionCollectorBuilder::new(shard_messenger).channel_id(self.0)
     }
+
+    /// Gets a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the channel is not a stage channel,
+    /// or if there is no stage instance currently.
+    pub async fn get_stage_instance(&self, http: impl AsRef<Http>) -> Result<StageInstance> {
+        http.as_ref().get_stage_instance(self.0).await
+    }
+
+    /// Creates a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the channel is not a stage channel,
+    /// or if there is already a stage instance currently.
+    pub async fn create_stage_instance<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<StageInstance>
+    where
+        F: FnOnce(&mut CreateStageInstance) -> &mut CreateStageInstance,
+    {
+        let mut instance = CreateStageInstance::default();
+        f(&mut instance);
+
+        let map = utils::hashmap_to_json_map(instance.0);
+
+        http.as_ref().create_stage_instance(&Value::Object(map)).await
+    }
+
+    /// Edits a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the channel is not a stage channel,
+    /// or if there is not stage instance currently.
+    pub async fn edit_stage_instance<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<StageInstance>
+    where
+        F: FnOnce(&mut EditStageInstance) -> &mut EditStageInstance,
+    {
+        let mut instance = EditStageInstance::default();
+        f(&mut instance);
+
+        let map = utils::hashmap_to_json_map(instance.0);
+
+        http.as_ref().edit_stage_instance(self.0, &Value::Object(map)).await
+    }
+
+    /// Deletes a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the channel is not a stage channel,
+    /// or if there is no stage instance currently.
+    pub async fn delete_stage_instance(&self, http: impl AsRef<Http>) -> Result<()> {
+        http.as_ref().delete_stage_instance(self.0).await
+    }
+
+    /// Creates a public thread that is connected to a message.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn create_public_thread<F>(
+        &self,
+        http: impl AsRef<Http>,
+        message_id: impl Into<MessageId>,
+        f: F,
+    ) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut CreateThread) -> &mut CreateThread,
+    {
+        let mut instance = CreateThread::default();
+        f(&mut instance);
+
+        let map = utils::hashmap_to_json_map(instance.0);
+
+        http.as_ref().create_public_thread(self.0, message_id.into().0, &map).await
+    }
+
+    /// Creates a private thread.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn create_private_thread<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut CreateThread) -> &mut CreateThread,
+    {
+        let mut instance = CreateThread::default();
+        instance.kind(ChannelType::PrivateThread);
+        f(&mut instance);
+
+        let map = utils::hashmap_to_json_map(instance.0);
+
+        http.as_ref().create_private_thread(self.0, &map).await
+    }
+
+    /// Gets the thread members, if this channel is a thread.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the channel is not a thread channel
+    pub async fn get_thread_members(&self, http: impl AsRef<Http>) -> Result<Vec<ThreadMember>> {
+        http.as_ref().get_channel_thread_members(self.0).await
+    }
+
+    /// Joins the thread, if this channel is a thread.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the channel is not a thread channel
+    pub async fn join_thread(&self, http: impl AsRef<Http>) -> Result<()> {
+        http.as_ref().join_thread_channel(self.0).await
+    }
+
+    /// Leaves the thread, if this channel is a thread.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the channel is not a thread channel
+    pub async fn leave_thread(&self, http: impl AsRef<Http>) -> Result<()> {
+        http.as_ref().leave_thread_channel(self.0).await
+    }
+
+    /// Adds a thread member, if this channel is a thread.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the channel is not a thread channel
+    pub async fn add_thread_member(&self, http: impl AsRef<Http>, user_id: UserId) -> Result<()> {
+        http.as_ref().add_thread_channel_member(self.0, user_id.into()).await
+    }
+
+    /// Removes a thread member, if this channel is a thread.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the channel is not a thread channel
+    pub async fn remove_thread_member(
+        &self,
+        http: impl AsRef<Http>,
+        user_id: UserId,
+    ) -> Result<()> {
+        http.as_ref().remove_thread_channel_member(self.0, user_id.into()).await
+    }
+
+    /// Gets all active threads of a channel.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the bot doesn't have the
+    /// permission to get it.
+    pub async fn get_active_threads(&self, http: impl AsRef<Http>) -> Result<ThreadsData> {
+        http.as_ref().get_channel_active_threads(self.0).await
+    }
+
+    /// Gets private archived threads of a channel.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the bot doesn't have the
+    /// permission to get it.
+    pub async fn get_archived_private_threads(
+        &self,
+        http: impl AsRef<Http>,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> Result<ThreadsData> {
+        http.as_ref().get_channel_archived_private_threads(self.0, before, limit).await
+    }
+
+    /// Gets public archived threads of a channel.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the bot doesn't have the
+    /// permission to get it.
+    pub async fn get_archived_public_threads(
+        &self,
+        http: impl AsRef<Http>,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> Result<ThreadsData> {
+        http.as_ref().get_channel_archived_public_threads(self.0, before, limit).await
+    }
+
+    /// Gets private archived threads joined by the current user of a channel.
+    ///
+    /// # Errors
+    ///
+    /// It may return an [`Error::Http`] if the bot doesn't have the
+    /// permission to get it.
+    pub async fn get_joined_archived_private_threads(
+        &self,
+        http: impl AsRef<Http>,
+        before: Option<u64>,
+        limit: Option<u64>,
+    ) -> Result<ThreadsData> {
+        http.as_ref().get_channel_joined_archived_private_threads(self.0, before, limit).await
+    }
 }
 
 impl From<Channel> for ChannelId {
