@@ -10,7 +10,15 @@ use futures::stream::StreamExt;
 #[cfg(feature = "model")]
 use crate::builder::EditChannel;
 #[cfg(feature = "model")]
-use crate::builder::{CreateInvite, CreateMessage, EditMessage, EditVoiceState, GetMessages};
+use crate::builder::{
+    CreateInvite,
+    CreateMessage,
+    CreateThread,
+    EditMessage,
+    EditVoiceState,
+    GetMessages,
+};
+use crate::builder::{CreateStageInstance, EditStageInstance};
 #[cfg(feature = "cache")]
 use crate::cache::Cache;
 #[cfg(feature = "collector")]
@@ -71,11 +79,13 @@ pub struct GuildChannel {
     /// The name of the channel.
     pub name: String,
     /// Permission overwrites for [`Member`]s and for [`Role`]s.
+    #[serde(default)]
     pub permission_overwrites: Vec<PermissionOverwrite>,
     /// The position of the channel.
     ///
     /// The default text channel will _almost always_ have a position of `-1` or
     /// `0`.
+    #[serde(default)]
     pub position: i64,
     /// The topic of the channel.
     ///
@@ -104,6 +114,26 @@ pub struct GuildChannel {
     pub rtc_region: Option<String>,
     /// The video quality mode for a voice channel.
     pub video_quality_mode: Option<VideoQualityMode>,
+    /// An approximate count of messages in the thread, stops counting at 50.
+    ///
+    /// **Note**: This is only available on thread channels.
+    pub message_count: Option<u8>,
+    /// An approximate count of users in a thread, stops counting at 50.
+    ///
+    /// **Note**: This is only available on thread channels.
+    pub member_count: Option<u8>,
+    /// The thread metadata.
+    ///
+    /// **Note**: This is only available on thread channels.
+    pub thread_metadata: Option<ThreadMetadata>,
+    /// Thread member object for the current user, if they have joined the thread,
+    /// only included on certain API endpoints.
+    pub member: Option<ThreadMember>,
+    /// Default duration for newly created threads, in minutes, to automatically
+    /// archive the thread after recent activity.
+    ///
+    /// **Note**: It can currently only be set to 60, 1440, 4320, 10080.
+    pub default_auto_archive_duration: Option<u64>,
 }
 
 #[cfg(feature = "model")]
@@ -934,7 +964,9 @@ impl GuildChannel {
             if let Some(cache) = cache_http.cache() {
                 let req = Permissions::SEND_MESSAGES;
 
-                if !utils::user_has_perms(&cache, self.id, Some(self.guild_id), req).await? {
+                if let Ok(false) =
+                    utils::user_has_perms(&cache, self.id, Some(self.guild_id), req).await
+                {
                     return Err(Error::Model(ModelError::InvalidPermissions(req)));
                 }
             }
@@ -1077,44 +1109,44 @@ impl GuildChannel {
         }
     }
 
-    /// Returns a future that will await one message by this guild.
+    /// Returns a future that will await one message by this guild channel.
     #[cfg(feature = "collector")]
     #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reply<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
     ) -> CollectReply<'a> {
-        CollectReply::new(shard_messenger).guild_id(self.id.0)
+        CollectReply::new(shard_messenger).channel_id(self.id.0)
     }
 
-    /// Returns a stream builder which can be awaited to obtain a stream of messages sent by this guild.
+    /// Returns a stream builder which can be awaited to obtain a stream of messages sent by this guild channel.
     #[cfg(feature = "collector")]
     #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_replies<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
     ) -> MessageCollectorBuilder<'a> {
-        MessageCollectorBuilder::new(shard_messenger).guild_id(self.id.0)
+        MessageCollectorBuilder::new(shard_messenger).channel_id(self.id.0)
     }
 
-    /// Await a single reaction by this guild.
+    /// Await a single reaction by this guild channel.
     #[cfg(feature = "collector")]
     #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
     ) -> CollectReaction<'a> {
-        CollectReaction::new(shard_messenger).guild_id(self.id.0)
+        CollectReaction::new(shard_messenger).channel_id(self.id.0)
     }
 
-    /// Returns a stream builder which can be awaited to obtain a stream of reactions sent by this guild.
+    /// Returns a stream builder which can be awaited to obtain a stream of reactions sent by this guild channel.
     #[cfg(feature = "collector")]
     #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
     ) -> ReactionCollectorBuilder<'a> {
-        ReactionCollectorBuilder::new(shard_messenger).guild_id(self.id.0)
+        ReactionCollectorBuilder::new(shard_messenger).channel_id(self.id.0)
     }
 
     /// Creates a webhook with only a name.
@@ -1169,6 +1201,109 @@ impl GuildChannel {
 
         self.id.create_webhook_with_avatar(&http, name, avatar).await
     }
+
+    /// Gets a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ModelError::InvalidChannelType`] if the channel is not a stage channel.
+    /// Returns [`Error::Http`] if there is no stage instance currently.
+    pub async fn get_stage_instance(&self, http: impl AsRef<Http>) -> Result<StageInstance> {
+        if self.kind.num() != 13 {
+            return Err(Error::Model(ModelError::InvalidChannelType));
+        }
+
+        self.id.get_stage_instance(http).await
+    }
+
+    /// Creates a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ModelError::InvalidChannelType`] if the channel is not a stage channel.
+    /// Returns [`Error::Http`] if there is already a stage instance currently.
+    pub async fn create_stage_instance<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<StageInstance>
+    where
+        F: FnOnce(&mut CreateStageInstance) -> &mut CreateStageInstance,
+    {
+        if self.kind.num() != 13 {
+            return Err(Error::Model(ModelError::InvalidChannelType));
+        }
+
+        self.id.create_stage_instance(http, f).await
+    }
+
+    /// Edits a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ModelError::InvalidChannelType`] if the channel is not a stage channel.
+    /// Returns [`Error::Http`] if there is no stage instance currently.
+    pub async fn edit_stage_instance<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<StageInstance>
+    where
+        F: FnOnce(&mut EditStageInstance) -> &mut EditStageInstance,
+    {
+        if self.kind.num() != 13 {
+            return Err(Error::Model(ModelError::InvalidChannelType));
+        }
+
+        self.id.edit_stage_instance(http, f).await
+    }
+
+    /// Deletes a stage instance.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`ModelError::InvalidChannelType`] if the channel is not a stage channel.
+    /// Returns [`Error::Http`] if there is no stage instance currently.
+    pub async fn delete_stage_instance(&self, http: impl AsRef<Http>) -> Result<()> {
+        if self.kind.num() != 13 {
+            return Err(Error::Model(ModelError::InvalidChannelType));
+        }
+
+        self.id.delete_stage_instance(http).await
+    }
+
+    /// Creates a public thread that is connected to a message.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn create_public_thread<F>(
+        &self,
+        http: impl AsRef<Http>,
+        message_id: impl Into<MessageId>,
+        f: F,
+    ) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut CreateThread) -> &mut CreateThread,
+    {
+        self.id.create_public_thread(http, message_id, f).await
+    }
+
+    /// Creates a private thread.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn create_private_thread<F>(
+        &self,
+        http: impl AsRef<Http>,
+        f: F,
+    ) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut CreateThread) -> &mut CreateThread,
+    {
+        self.id.create_private_thread(http, f).await
+    }
 }
 
 impl Display for GuildChannel {
@@ -1177,3 +1312,18 @@ impl Display for GuildChannel {
         Display::fmt(&self.id.mention(), f)
     }
 }
+
+/// A partial guild channel.
+#[derive(Clone, Debug, Deserialize, Serialize)]
+pub struct PartialGuildChannel {
+    /// The channel Id.
+    pub id: ChannelId,
+    /// The channel guild Id.
+    pub guild_id: GuildId,
+    /// The channel category Id.
+    #[serde(rename = "parent_id")]
+    pub category_id: ChannelId,
+    /// The channel type.
+    #[serde(rename = "type")]
+    pub kind: ChannelType,
+}
