@@ -29,7 +29,7 @@ use crate::collector::{CollectReaction, ReactionCollectorBuilder};
 #[cfg(feature = "model")]
 use crate::http::{CacheHttp, Http};
 #[cfg(feature = "unstable_discord_api")]
-use crate::model::interactions::MessageInteraction;
+use crate::model::interactions::{message_component::ActionRow, MessageInteraction};
 use crate::model::prelude::*;
 #[cfg(feature = "model")]
 use crate::model::utils::U64Visitor;
@@ -132,7 +132,7 @@ pub struct Message {
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     #[serde(default)]
-    pub components: Vec<Component>,
+    pub components: Vec<ActionRow>,
 }
 
 #[cfg(feature = "model")]
@@ -348,13 +348,8 @@ impl Message {
             builder.content(&self.content);
         }
 
-        if let Some(embed) = self.embeds.get(0) {
-            let embed = CreateEmbed::from(embed.clone());
-            builder.embed(|e| {
-                *e = embed;
-                e
-            });
-        }
+        let embeds: Vec<_> = self.embeds.iter().map(|e| CreateEmbed::from(e.clone())).collect();
+        builder.set_embeds(embeds);
 
         f(&mut builder);
 
@@ -937,53 +932,59 @@ impl Message {
     }
 
     pub(crate) fn check_embed_length(map: &JsonMap) -> Result<()> {
-        let embed = match map.get("embed") {
-            Some(&Value::Object(ref value)) => value,
+        let embeds = match map.get("embeds") {
+            Some(&Value::Array(ref value)) => value,
             _ => return Ok(()),
         };
 
-        let mut total: usize = 0;
+        if embeds.len() > 10 {
+            return Err(Error::Model(ModelError::EmbedAmount));
+        }
 
-        if let Some(&Value::Object(ref author)) = embed.get("author") {
-            if let Some(&Value::Object(ref name)) = author.get("name") {
-                total += name.len();
+        for embed in embeds {
+            let mut total: usize = 0;
+
+            if let Some(&Value::Object(ref author)) = embed.get("author") {
+                if let Some(&Value::Object(ref name)) = author.get("name") {
+                    total += name.len();
+                }
             }
-        }
 
-        if let Some(&Value::String(ref description)) = embed.get("description") {
-            total += description.len();
-        }
+            if let Some(&Value::String(ref description)) = embed.get("description") {
+                total += description.len();
+            }
 
-        if let Some(&Value::Array(ref fields)) = embed.get("fields") {
-            for field_as_value in fields {
-                if let Value::Object(ref field) = *field_as_value {
-                    if let Some(&Value::String(ref field_name)) = field.get("name") {
-                        total += field_name.len();
-                    }
+            if let Some(&Value::Array(ref fields)) = embed.get("fields") {
+                for field_as_value in fields {
+                    if let Value::Object(ref field) = *field_as_value {
+                        if let Some(&Value::String(ref field_name)) = field.get("name") {
+                            total += field_name.len();
+                        }
 
-                    if let Some(&Value::String(ref field_value)) = field.get("value") {
-                        total += field_value.len();
+                        if let Some(&Value::String(ref field_value)) = field.get("value") {
+                            total += field_value.len();
+                        }
                     }
                 }
             }
-        }
 
-        if let Some(&Value::Object(ref footer)) = embed.get("footer") {
-            if let Some(&Value::String(ref text)) = footer.get("text") {
-                total += text.len();
+            if let Some(&Value::Object(ref footer)) = embed.get("footer") {
+                if let Some(&Value::String(ref text)) = footer.get("text") {
+                    total += text.len();
+                }
+            }
+
+            if let Some(&Value::String(ref title)) = embed.get("title") {
+                total += title.len();
+            }
+
+            if total > constants::EMBED_MAX_LENGTH {
+                let overflow = total - constants::EMBED_MAX_LENGTH;
+                return Err(Error::Model(ModelError::EmbedTooLarge(overflow)));
             }
         }
 
-        if let Some(&Value::String(ref title)) = embed.get("title") {
-            total += title.len();
-        }
-
-        if total <= constants::EMBED_MAX_LENGTH {
-            Ok(())
-        } else {
-            let overflow = total - constants::EMBED_MAX_LENGTH;
-            Err(Error::Model(ModelError::EmbedTooLarge(overflow)))
-        }
+        Ok(())
     }
 }
 
@@ -1060,10 +1061,18 @@ pub enum MessageType {
     GuildDiscoveryDisqualified = 14,
     /// An indicator that the guild is requalified for Discovery Feature
     GuildDiscoveryRequalified = 15,
+    /// The first warning before guild discovery removal.
+    GuildDiscoveryGracePeriodInitialWarning = 16,
+    /// The last warning before guild discovery removal.
+    GuildDiscoveryGracePeriodFinalWarning = 17,
+    /// Message sent to inform users that a thread was created.
+    ThreadCreated = 18,
     /// A message reply.
     InlineReply = 19,
     /// A slash command.
     ApplicationCommand = 20,
+    /// A thread start message.
+    ThreadStarterMessage = 21,
     /// Server setup tips.
     GuildInviteReminder = 22,
     /// An indicator that the message is of unknown type.
@@ -1086,8 +1095,13 @@ enum_number!(MessageType {
     ChannelFollowAdd,
     GuildDiscoveryDisqualified,
     GuildDiscoveryRequalified,
+    GuildDiscoveryGracePeriodInitialWarning,
+    GuildDiscoveryGracePeriodFinalWarning
+    ThreadCreated,
     InlineReply,
     ApplicationCommand,
+    ThreadStarterMessage,
+    GuildInviteReminder
 });
 
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, PartialOrd, Ord)]
@@ -1204,6 +1218,8 @@ __impl_bitflags! {
         SOURCE_MESSAGE_DELETED = 0b0000_0000_0000_0000_0000_0000_0000_1000;
         /// This message came from the urgent message system.
         URGENT = 0b0000_0000_0000_0000_0000_0000_0001_0000;
+        /// This message has an associated thread, with the same id as the message.
+        HAS_THREAD = 0b0000_0000_0000_0000_0000_0000_0010_0000;
         /// This message is only visible to the user who invoked the Interaction.
         EPHEMERAL = 0b0000_0000_0000_0000_0000_0000_0100_0000;
         /// This message is an Interaction Response and the bot is "thinking".
