@@ -68,6 +68,11 @@ pub struct Activity {
     pub session_id: Option<String>,
     /// The Stream URL if [`Self::kind`] is [`ActivityType::Streaming`].
     pub url: Option<String>,
+    /// The buttons of this activity.
+    ///
+    /// **Note**: There can only be up to 2 buttons.
+    #[serde(default)]
+    pub buttons: Vec<ActivityButton>,
 }
 
 #[cfg(feature = "model")]
@@ -119,6 +124,7 @@ impl Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id: None,
             url: None,
+            buttons: vec![],
         }
     }
 
@@ -173,6 +179,7 @@ impl Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id: None,
             url: Some(url.to_string()),
+            buttons: vec![],
         }
     }
 
@@ -223,6 +230,7 @@ impl Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id: None,
             url: None,
+            buttons: vec![],
         }
     }
 
@@ -273,6 +281,7 @@ impl Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id: None,
             url: None,
+            buttons: vec![],
         }
     }
 
@@ -323,6 +332,7 @@ impl Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id: None,
             url: None,
+            buttons: vec![],
         }
     }
 }
@@ -407,6 +417,15 @@ impl<'de> Deserialize<'de> for Activity {
 
         let url = map.remove("url").and_then(|v| serde_json::from_value::<String>(v).ok());
 
+        let buttons = match map.contains_key("buttons") {
+            true => map
+                .remove("buttons")
+                .ok_or_else(|| DeError::custom("expected buttons"))
+                .and_then(deserialize_buttons)
+                .map_err(DeError::custom)?,
+            false => vec![],
+        };
+
         Ok(Activity {
             application_id,
             assets,
@@ -425,10 +444,23 @@ impl<'de> Deserialize<'de> for Activity {
             #[cfg(feature = "unstable_discord_api")]
             session_id,
             url,
+            buttons,
         })
     }
 }
 
+#[derive(Clone, Debug, Serialize, Deserialize)]
+#[non_exhaustive]
+pub struct ActivityButton {
+    /// The text shown on the button.
+    pub label: String,
+    /// The url opened when clicking the button.
+    ///
+    /// **Note**: Bots cannot access activity button URL.
+    #[serde(default)]
+    pub url: String,
+}
+
 /// The assets for an activity.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[non_exhaustive]
