@@ -32,7 +32,7 @@ use crate::{
         CreateApplicationCommands,
         CreateApplicationCommandsPermissions,
     },
-    model::interactions::ApplicationCommand,
+    model::interactions::application_command::{ApplicationCommand, ApplicationCommandPermission},
 };
 
 #[cfg(feature = "model")]
@@ -953,6 +953,27 @@ impl GuildId {
         http.as_ref().edit_guild_channel_positions(self.0, &Value::Array(items)).await
     }
 
+    /// Returns a list of [`Member`]s in a [`Guild`] whose username or nickname
+    /// starts with a provided string.
+    ///
+    /// Optionally pass in the `limit` to limit the number of results.
+    /// Minimum value is 1, maximum and default value is 1000.
+    ///
+    /// # Errors
+    ///
+    /// Returns an [`Error::Http`] if the API returns an error.
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    #[inline]
+    pub async fn search_members(
+        self,
+        http: impl AsRef<Http>,
+        query: &str,
+        limit: Option<u64>,
+    ) -> Result<Vec<Member>> {
+        http.as_ref().search_guild_members(self.0, query, limit).await
+    }
+
     /// Returns the Id of the shard associated with the guild.
     ///
     /// When the cache is enabled this will automatically retrieve the total
@@ -1132,8 +1153,8 @@ impl GuildId {
     ///
     /// Returns the same possible errors as [`create_global_application_command`].
     ///
-    /// [`ApplicationCommand`]: crate::model::interactions::ApplicationCommand
-    /// [`create_global_application_command`]: crate::model::interactions::ApplicationCommand::create_global_application_command
+    /// [`ApplicationCommand`]: crate::model::interactions::application_command::ApplicationCommand
+    /// [`create_global_application_command`]: crate::model::interactions::application_command::ApplicationCommand::create_global_application_command
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn create_application_command<F>(
@@ -1148,13 +1169,10 @@ impl GuildId {
         http.as_ref().create_guild_application_command(self.0, &Value::Object(map)).await
     }
 
-    /// Same as [`create_application_command`], but allows to create more
-    /// than one command per call.
-    ///
-    /// [`create_application_command`]: Self::create_application_command
+    /// Overrides all guild application commands.
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
-    pub async fn create_application_commands<F>(
+    pub async fn set_application_commands<F>(
         &self,
         http: impl AsRef<Http>,
         f: F,
@@ -1173,7 +1191,7 @@ impl GuildId {
     ///
     /// **Note**: It will update instantly.
     ///
-    /// [`ApplicationCommandPermission`]: crate::model::interactions::ApplicationCommandPermission
+    /// [`ApplicationCommandPermission`]: crate::model::interactions::application_command::ApplicationCommandPermission
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn create_application_command_permission<F>(
@@ -1199,13 +1217,10 @@ impl GuildId {
             .await
     }
 
-    /// Same as [`create_application_command_permission`] but allows to create
-    /// more than one permission per call.
-    ///
-    /// [`create_application_command_permission`]: Self::create_application_command_permission
+    /// Overrides all application commands permissions.
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
-    pub async fn create_application_commands_permissions<F>(
+    pub async fn set_application_commands_permissions<F>(
         &self,
         http: impl AsRef<Http>,
         f: F,
