@@ -3,7 +3,10 @@ use std::borrow::Cow;
 use std::cmp::Reverse;
 use std::fmt::{Display, Formatter, Result as FmtResult};
 
+#[cfg(feature = "model")]
+use bitflags::__impl_bitflags;
 use chrono::{DateTime, Utc};
+use serde::{Serialize, Serializer};
 
 #[cfg(feature = "model")]
 use crate::builder::EditMember;
@@ -54,6 +57,8 @@ pub struct Member {
     #[cfg(feature = "unstable_discord_api")]
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub permissions: Option<Permissions>,
+    /// The guild avatar hash
+    pub avatar: Option<String>,
 }
 
 #[cfg(feature = "model")]
@@ -249,7 +254,7 @@ impl Member {
         let mut highest = None;
 
         for role_id in &self.roles {
-            if let Some(role) = guild_roles.get(&role_id) {
+            if let Some(role) = guild_roles.get(role_id) {
                 // Skip this role if this role in iteration has:
                 //
                 // - a position less than the recorded highest
@@ -405,12 +410,15 @@ impl Member {
         &self,
         cache_http: impl CacheHttp + AsRef<Cache>,
     ) -> Result<Permissions> {
-        let guild = match cache_http.as_ref().guild(self.guild_id).await {
-            Some(guild) => guild,
-            None => return Err(From::from(ModelError::GuildNotFound)),
-        };
+        let perms_opt = cache_http
+            .as_ref()
+            .guild_field(self.guild_id, |guild| guild._member_permission_from_member(self))
+            .await;
 
-        guild.member_permissions(cache_http, self.user.id).await
+        match perms_opt {
+            Some(perms) => Ok(perms),
+            None => Err(From::from(ModelError::GuildNotFound)),
+        }
     }
 
     /// Removes a [`Role`] from the member, editing its roles in-place if the
@@ -510,6 +518,24 @@ impl Member {
     pub async fn unban(&self, http: impl AsRef<Http>) -> Result<()> {
         http.as_ref().remove_ban(self.guild_id.0, self.user.id.0).await
     }
+
+    /// Returns the formatted URL of the member's per guild avatar, if one exists.
+    ///
+    /// This will produce a WEBP image URL, or GIF if the member has a GIF avatar.
+    #[inline]
+    pub fn avatar_url(&self) -> Option<String> {
+        avatar_url(self.guild_id, self.user.id, self.avatar.as_ref())
+    }
+
+    /// Retrieves the URL to the current member's avatar, falling back to the
+    /// user's avatar, then default avatar if needed.
+    ///
+    /// This will call [`Self::avatar_url`] first, and if that returns [`None`],
+    /// it then falls back to [`User::face()`].
+    #[inline]
+    pub fn face(&self) -> String {
+        self.avatar_url().unwrap_or_else(|| self.user.face())
+    }
 }
 
 impl Display for Member {
@@ -566,3 +592,56 @@ pub struct PartialMember {
     #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub permissions: Option<Permissions>,
 }
+
+#[cfg(feature = "model")]
+fn avatar_url(guild_id: GuildId, user_id: UserId, hash: Option<&String>) -> Option<String> {
+    hash.map(|hash| {
+        let ext = if hash.starts_with("a_") { "gif" } else { "webp" };
+
+        cdn!("/guilds/{}/users/{}/avatars/{}.{}?size=1024", guild_id.0, user_id.0, hash, ext)
+    })
+}
+
+#[derive(Clone, Debug, Deserialize, Serialize)]
+#[non_exhaustive]
+pub struct ThreadMember {
+    /// The id of the thread.
+    pub id: Option<ChannelId>,
+    /// The id of the user.
+    pub user_id: Option<UserId>,
+    /// The time the current user last joined the thread.
+    pub join_timestamp: DateTime<Utc>,
+    /// Any user-thread settings, currently only used for notifications
+    pub flags: ThreadMemberFlags,
+}
+
+/// Describes extra features of the message.
+#[derive(Copy, PartialEq, Eq, Clone, PartialOrd, Ord, Hash)]
+pub struct ThreadMemberFlags {
+    pub bits: u64,
+}
+
+__impl_bitflags! {
+    ThreadMemberFlags: u64 {
+        // Not documented.
+        NOTIFICATIONS = 0b0000_0000_0000_0000_0000_0000_0000_0001;
+    }
+}
+
+impl<'de> Deserialize<'de> for ThreadMemberFlags {
+    fn deserialize<D>(deserializer: D) -> StdResult<Self, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        Ok(ThreadMemberFlags::from_bits_truncate(deserializer.deserialize_u64(U64Visitor)?))
+    }
+}
+
+impl Serialize for ThreadMemberFlags {
+    fn serialize<S>(&self, serializer: S) -> StdResult<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        serializer.serialize_u64(self.bits())
+    }
+}
