@@ -404,6 +404,11 @@ mod test {
                 slow_mode_rate: Some(0),
                 rtc_region: None,
                 video_quality_mode: None,
+                message_count: None,
+                member_count: None,
+                thread_metadata: None,
+                member: None,
+                default_auto_archive_duration: None,
             });
             let emoji = Emoji {
                 animated: false,
@@ -447,6 +452,7 @@ mod test {
                 premium_since: None,
                 #[cfg(feature = "unstable_discord_api")]
                 permissions: None,
+                avatar: None,
             };
 
             assert_eq!(ChannelId(1).mention().to_string(), "<#1>");
