@@ -12,6 +12,7 @@
 
 pub use super::application::*;
 pub use super::channel::*;
+pub use super::connection::*;
 pub use super::event::*;
 pub use super::gateway::*;
 pub use super::guild::*;
@@ -21,6 +22,7 @@ pub use super::id::*;
 pub use super::interactions::*;
 pub use super::invite::*;
 pub use super::misc::*;
+pub use super::oauth2::*;
 pub use super::permissions::*;
 pub use super::user::*;
 pub use super::voice::*;
