@@ -1,14 +1,14 @@
 //! A set of utilities to help with common use cases that are not required to
 //! fully use the library.
 
+#[cfg(all(feature = "client", feature = "cache"))]
+mod argument_convert;
 mod colour;
 mod custom_message;
 mod message_builder;
-#[cfg(feature = "client")]
-mod parse;
 
-#[cfg(feature = "client")]
-pub use parse::*;
+#[cfg(all(feature = "client", feature = "cache"))]
+pub use argument_convert::*;
 
 pub use self::{
     colour::Colour,
@@ -565,7 +565,7 @@ async fn clean_roles(cache: impl AsRef<Cache>, s: &mut String) {
                 *s = if let Some(role) = id.to_role_cached(&cache).await {
                     s.replace(&to_replace, &format!("@{}", &role.name))
                 } else {
-                    s.replace(&to_replace, &"@deleted-role")
+                    s.replace(&to_replace, "@deleted-role")
                 };
             } else {
                 let id = &s[mention_start..mention_end].to_string();
@@ -573,7 +573,7 @@ async fn clean_roles(cache: impl AsRef<Cache>, s: &mut String) {
                 if !id.is_empty() && id.as_bytes().iter().all(u8::is_ascii_digit) {
                     let to_replace = format!("<@&{}>", id);
 
-                    *s = s.replace(&to_replace, &"@deleted-role");
+                    *s = s.replace(&to_replace, "@deleted-role");
                 } else {
                     progress = mention_end;
                 }
@@ -603,7 +603,7 @@ async fn clean_channels(cache: &impl AsRef<Cache>, s: &mut String) {
                     let replacement = format!("#{}", &channel.name);
                     s.replace(&to_replace, &replacement)
                 } else {
-                    s.replace(&to_replace, &"#deleted-channel")
+                    s.replace(&to_replace, "#deleted-channel")
                 };
             } else {
                 let id = &s[mention_start..mention_end].to_string();
@@ -611,7 +611,7 @@ async fn clean_channels(cache: &impl AsRef<Cache>, s: &mut String) {
                 if !id.is_empty() && id.as_bytes().iter().all(u8::is_ascii_digit) {
                     let to_replace = format!("<#{}>", id);
 
-                    *s = s.replace(&to_replace, &"#deleted-channel");
+                    *s = s.replace(&to_replace, "#deleted-channel");
                 } else {
                     progress = mention_end;
                 }
@@ -685,7 +685,7 @@ async fn clean_users(
                     let code_start = if has_exclamation { "<@!" } else { "<@" };
                     let to_replace = format!("{}{}>", code_start, id);
 
-                    *s = s.replace(&to_replace, &"@invalid-user");
+                    *s = s.replace(&to_replace, "@invalid-user");
                 } else {
                     progress = mention_end;
                 }
@@ -865,11 +865,14 @@ mod test {
             approximate_member_count: None,
             approximate_presence_count: None,
             nsfw: false,
+            nsfw_level: NsfwLevel::Default,
             max_video_channel_users: None,
             max_presences: None,
             max_members: None,
             widget_enabled: Some(false),
             widget_channel_id: None,
+            stage_instances: vec![],
+            threads: vec![],
         };
 
         let member = Member {
@@ -884,6 +887,7 @@ mod test {
             premium_since: None,
             #[cfg(feature = "unstable_discord_api")]
             permissions: None,
+            avatar: None,
         };
 
         let role = Role {
@@ -916,6 +920,11 @@ mod test {
             slow_mode_rate: Some(0),
             rtc_region: None,
             video_quality_mode: None,
+            message_count: None,
+            member_count: None,
+            thread_metadata: None,
+            member: None,
+            default_auto_archive_duration: None,
         };
 
         let cache = Arc::new(Cache::default());
